==> bettertrims-4.0.2%2B1.21.1-fabric-sources.jar: com/bawnorton/bettertrims/client/tooltip/condition/predicate/data/partial/EnchantmentsPredicatePartialAdder.java <==
package com.bawnorton.bettertrims.client.tooltip.condition.predicate.data.partial;

import com.bawnorton.bettertrims.client.tooltip.component.CompositeContainerComponent;
import com.bawnorton.bettertrims.client.tooltip.condition.LootConditionTooltips;
import com.bawnorton.bettertrims.client.tooltip.condition.predicate.PredicateTooltip;
import com.bawnorton.bettertrims.client.tooltip.util.Styler;
import java.util.List;
import java.util.Optional;
import net.minecraft.class_1887;
import net.minecraft.class_2035;
import net.minecraft.class_2096;
import net.minecraft.class_2561;
import net.minecraft.class_638;
import net.minecraft.class_6885;
import net.minecraft.class_7924;
import net.minecraft.class_9356;
//? if >=1.21.8 {
/*import com.bawnorton.bettertrims.client.mixin.accessor.EnchantmentsPredicateAccessor;
*///?} else {
import com.bawnorton.bettertrims.client.mixin.accessor.ItemsEnchantmentsPredicateAccessor;
//?}

public final class EnchantmentsPredicatePartialAdder<T extends /*$ enchantments_predicate >>*/ class_9356 > implements PartialAdder<T> {
	@Override
	public void addToBuilder(class_638 level, T predicate, LootConditionTooltips.State state, CompositeContainerComponent.Builder builder) {
		//? if >=1.21.8 {
		/*EnchantmentsPredicateAccessor enchantmentsPredicate = (EnchantmentsPredicateAccessor) predicate;
		 *///?} else {
		ItemsEnchantmentsPredicateAccessor enchantmentsPredicate = (ItemsEnchantmentsPredicateAccessor) predicate;
		//?}
		List<class_2035> enchantmentPredicates = enchantmentsPredicate.bettertrims$enchantments();
		if (enchantmentPredicates.isEmpty()) {
			builder.translate(key("enchantments.any"), Styler::condition);
			return;
		}
		boolean useAnd = false;
		for (class_2035 enchantmentPredicate : enchantmentPredicates) {
			Optional<class_6885<class_1887>> enchantments = enchantmentPredicate.comp_2665();
			class_2096.class_2100 enchLevel = enchantmentPredicate.comp_1749();
			CompositeContainerComponent.Builder enchBuilder = CompositeContainerComponent.builder();
			if (enchantments.isPresent()) {
				class_6885<class_1887> enchantmentHolderSet = enchantments.orElseThrow();
				PredicateTooltip.addRegisteredElementsToBuilder(
						level,
						useAnd ? "bettertrims.tooltip.and" : enchantmentHolderSet.method_40247() == 1 ? key("enchantments.matches") : key("enchantments.matches_multiple"),
						class_7924.field_41265,
						enchantmentHolderSet,
						(enchantment, appender) -> {
							if (!enchLevel.method_9041()) {
								appender.space();
								PredicateTooltip.addMinMaxToBuilder(
										key("enchantments.level"),
										false,
										enchLevel,
										value -> class_2561.method_43471("enchantment.level.%s".formatted("%.0f".formatted(value))),
										state, appender
								);
							}
							return enchantment.comp_2686();
						},
						state, enchBuilder
				);
				useAnd = true;
			} else {
				enchBuilder.space()
						.translate(key("enchantments.any"), Styler::condition)
						.space();
				if (!enchLevel.method_9041()) {
					PredicateTooltip.addMinMaxToBuilder(
							key("enchantments.level"),
							false,
							enchLevel,
							value -> class_2561.method_43471("enchantment.level.%s".formatted("%.0f".formatted(value))),
							state, enchBuilder
					);
				}
			}
			builder.component(enchBuilder.build());
		}
	}
}

==> bettertrims-4.0.3%2B1.21.8-fabric-sources.jar: com/bawnorton/bettertrims/client/tooltip/condition/predicate/data/partial/EnchantmentsPredicatePartialAdder.java <==
package com.bawnorton.bettertrims.client.tooltip.condition.predicate.data.partial;

import com.bawnorton.bettertrims.client.tooltip.component.CompositeContainerComponent;
import com.bawnorton.bettertrims.client.tooltip.condition.LootConditionTooltips;
import com.bawnorton.bettertrims.client.tooltip.condition.predicate.PredicateTooltip;
import com.bawnorton.bettertrims.client.tooltip.util.Styler;
import java.util.List;
import java.util.Optional;
import net.minecraft.class_1887;
import net.minecraft.class_2035;
import net.minecraft.class_2096;
import net.minecraft.class_2561;
import net.minecraft.class_638;
import net.minecraft.class_6885;
import net.minecraft.class_7924;
import net.minecraft.class_9356;
//? if >=1.21.8 {
import com.bawnorton.bettertrims.client.mixin.accessor.EnchantmentsPredicateAccessor;
//?} else {
/*import com.bawnorton.bettertrims.client.mixin.accessor.ItemsEnchantmentsPredicateAccessor;
*///?}

public final class EnchantmentsPredicatePartialAdder<T extends /*$ enchantments_predicate >>*/ class_9356 > implements PartialAdder<T> {
	@Override
	public void addToBuilder(class_638 level, T predicate, LootConditionTooltips.State state, CompositeContainerComponent.Builder builder) {
		//? if >=1.21.8 {
		EnchantmentsPredicateAccessor enchantmentsPredicate = (EnchantmentsPredicateAccessor) predicate;
		 //?} else {
		/*ItemsEnchantmentsPredicateAccessor enchantmentsPredicate = (ItemsEnchantmentsPredicateAccessor) predicate;
		*///?}
		List<class_2035> enchantmentPredicates = enchantmentsPredicate.bettertrims$enchantments();
		if (enchantmentPredicates.isEmpty()) {
			builder.translate(key("enchantments.any"), Styler::condition);
			return;
		}
		boolean useAnd = false;
		for (class_2035 enchantmentPredicate : enchantmentPredicates) {
			Optional<class_6885<class_1887>> enchantments = enchantmentPredicate.comp_2665();
			class_2096.class_2100 enchLevel = enchantmentPredicate.comp_1749();
			CompositeContainerComponent.Builder enchBuilder = CompositeContainerComponent.builder();
			if (enchantments.isPresent()) {
				class_6885<class_1887> enchantmentHolderSet = enchantments.orElseThrow();
				PredicateTooltip.addRegisteredElementsToBuilder(
						level,
						useAnd ? "bettertrims.tooltip.and" : enchantmentHolderSet.method_40247() == 1 ? key("enchantments.matches") : key("enchantments.matches_multiple"),
						class_7924.field_41265,
						enchantmentHolderSet,
						(enchantment, appender) -> {
							if (!enchLevel.method_9041()) {
								appender.space();
								PredicateTooltip.addMinMaxToBuilder(
										key("enchantments.level"),
										false,
										enchLevel,
										value -> class_2561.method_43471("enchantment.level.%s".formatted("%.0f".formatted(value))),
										state, appender
								);
							}
							return enchantment.comp_2686();
						},
						state, enchBuilder
				);
				useAnd = true;
			} else {
				enchBuilder.space()
						.translate(key("enchantments.any"), Styler::condition)
						.space();
				if (!enchLevel.method_9041()) {
					PredicateTooltip.addMinMaxToBuilder(
							key("enchantments.level"),
							false,
							enchLevel,
							value -> class_2561.method_43471("enchantment.level.%s".formatted("%.0f".formatted(value))),
							state, enchBuilder
					);
				}
			}
			builder.component(enchBuilder.build());
		}
	}
}
